Module: OpenTelemetry::Instrumentation

Defined in:
lib/opentelemetry/instrumentation.rb,
lib/opentelemetry/instrumentation/factory_bot.rb,
lib/opentelemetry/instrumentation/factory_bot/version.rb,
lib/opentelemetry/instrumentation/factory_bot/instrumentation.rb,
lib/opentelemetry/instrumentation/factory_bot/run_factory_subscriber.rb

Overview

Instrumentation should be able to handle the case when the library is not installed on a user's system.

Defined Under Namespace

Modules: FactoryBot